# Hydra Configuration Utilities

This package provides a simple way to define strongly typed dataclasses with support for non-primitive [Hydra](https://hydra.cc/) types. This project builds on both [Hydra](https://hydra.cc/) and [Hydra-Zen](https://mit-ll-responsible-ai.github.io/hydra-zen/), with the primary purpose to create an easy-to-use interface for _any_ command-line interface based on Hydra. See the [Documentation](https://AaronYoung5.github.io/hydra-config) for more details.

## Installation

```bash
pip install hydra-config
```
